@@ -1,7 +1,7 @@
 # File Manager: common file manipulation functions
+import os
 from pathlib import Path
 import pkg_resources
-import yaml
 
 
 def unique_filepath(filepath):
@@ -45,30 +45,16 @@ def export_file(content, path, overwrite=False):
     return path
 
 
-def load_config(path=None):
-    """Load a config file either from a user nominated location or, if no path is supplied, load the default config file from the *pinout* package.
-
-    :param path: [description], defaults to None
-    :type path: [type], optional
-    :return: [description]
-    :rtype: [type]
-    """
-    if path is None:
-        # Load default settings
-        path = "resources/config.yaml"
-        return yaml.safe_load(
-            pkg_resources.resource_string(__name__, path).decode("utf-8")
-        )
-    # Load user supplied settings
+def load_data(path):
     path = Path(path)
     with path.open() as f:
-        return yaml.safe_load(f)
+        return f.read()
 
 
 def duplicate(resource_name):
     """Duplicate resources from *pinout* package.
 
-    A variety of resources can be copied via this function. Access is also available via the command line::
+    A variety of resources can be copied via this function, access is available via the command line::
 
         py -m pinout.file_manager --duplicate <resource_name>
 
@@ -76,30 +62,19 @@ def duplicate(resource_name):
 
         + config
         + quick_start
-        + full_sample
-        + annotations
 
     :param resource_name: Name of resource to duplicate.
     :type resource_name: string
     """
 
     resources = {
-        "config": [(".", "config.yaml")],
         "quick_start": [
-            ("quick_start", "quick_start_config.yaml"),
-            ("quick_start", "quick_start_hardware.png"),
-            ("quick_start", "quick_start_pinout.py"),
-        ],
-        "full_sample": [
-            ("full_sample", "full_sample_config.yaml"),
-            ("full_sample", "full_sample_hardware.png"),
-            ("full_sample", "full_sample_pinout.py"),
-        ],
-        "annotations": [
-            ("annotations", "annotations.py"),
-            ("annotations", "annotations_config.yaml"),
-            ("shared", "hardware_board.svg"),
+            ("quick_start", "data.py"),
+            ("quick_start", "hardware.png"),
+            ("quick_start", "pinout_diagram.py"),
+            ("quick_start", "styles.css"),
         ],
+        "config": [("config.py",)],
     }
 
     resource_package = "pinout"
@@ -120,9 +95,10 @@ if __name__ == "__main__":
         "-d",
         "--duplicate",
         action="store",
-        choices=["quick_start", "full_sample", "config", "annotations"],
+        choices=["quick_start", "config"],
         help="duplicate pinout resources",
     )
+
     args = parser.parse_args()
     if args.duplicate:
-        duplicate(args.duplicate)
\ No newline at end of file
+        duplicate(args.duplicate)
